@@ -11,14 +11,7 @@ config = {
         "host": "localhost",
 
         # Flask port: DEVELOPMENT ONLY
-        "port": 5904,
-
-        # Logging configurations
-        "logging": {
-            "level": logging.INFO,
-            "format": "%(asctime)s | %(levelname)-8s | %(name)-20s | Line: %(lineno)-5d | %(message)s",
-            "datefmt": "%d-%m-%Y | %H:%M:%s"
-        },
+        "port": 5975,
 
         # metadata config
         "metadata": {
